==> xlniuxdata-vipgame-1.0.65-20170428.033419-75-sources.jar: com/xunlei/niux/data/vipgame/vo/expression/AdvAdvertise.java <==
package com.xunlei.niux.data.vipgame.vo.expression;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * @author ljm
 * @date 2017-4-25
 * @Descripter:
 */
@Table(tableName = "f_config_adv_advertise", pkFieldName = "adv_group_name", pkFieldAssign = true)
public class AdvAdvertise {
	private String f_begin_date;
	private String f_end_date;
	private String adv_plat;
	private String adv_group_name;
	private Integer price_type;
	private String unit_price;
	private Integer is_advertise;
	private Integer is_enabled;
	private String remark;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;

    @Column(columnName="f_begin_date",isWhereColumn=true,operator=Operator.GE)
	private String from_date;
    @Column(columnName="f_end_date",isWhereColumn=true,operator=Operator.LE)
	private String to_date;
    
	public String getFrom_date() {
		return from_date;
	}
	public void setFrom_date(String from_date) {
		this.from_date = from_date;
	}
	public String getTo_date() {
		return to_date;
	}
	public void setTo_date(String to_date) {
		this.to_date = to_date;
	}
	public String getF_begin_date() {
		return f_begin_date;
	}
	public void setF_begin_date(String f_begin_date) {
		this.f_begin_date = f_begin_date;
	}
	public String getF_end_date() {
		return f_end_date;
	}
	public void setF_end_date(String f_end_date) {
		this.f_end_date = f_end_date;
	}
	public String getAdv_plat() {
		return adv_plat;
	}
	public void setAdv_plat(String adv_plat) {
		this.adv_plat = adv_plat;
	}
	public String getAdv_group_name() {
		return adv_group_name;
	}
	public void setAdv_group_name(String adv_group_name) {
		this.adv_group_name = adv_group_name;
	}
	public String getUnit_price() {
		return unit_price;
	}
	public void setUnit_price(String unit_price) {
		this.unit_price = unit_price;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public Integer getPrice_type() {
		return price_type;
	}
	public void setPrice_type(Integer price_type) {
		this.price_type = price_type;
	}
	public Integer getIs_advertise() {
		return is_advertise;
	}
	public void setIs_advertise(Integer is_advertise) {
		this.is_advertise = is_advertise;
	}
	public Integer getIs_enabled() {
		return is_enabled;
	}
	public void setIs_enabled(Integer is_enabled) {
		this.is_enabled = is_enabled;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	@Override
	public String toString() {
		return "AdvAdvertise [f_begin_date=" + f_begin_date + ", f_end_date="
				+ f_end_date + ", adv_plat=" + adv_plat + ", adv_group_name="
				+ adv_group_name + ", price_type=" + price_type
				+ ", unit_price=" + unit_price + ", is_advertise="
				+ is_advertise + ", is_enabled=" + is_enabled + ", remark="
				+ remark + ", inputBy=" + inputBy + ", inputTime=" + inputTime
				+ ", editBy=" + editBy + ", editTime=" + editTime + "]";
	}
	
	
}

==> xlniuxdata-vipgame-1.0.65-20170531.123143-83-sources.jar: com/xunlei/niux/data/vipgame/vo/expression/AdvAdvertise.java <==
package com.xunlei.niux.data.vipgame.vo.expression;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * @author ljm
 * @date 2017-4-25
 * @Descripter:
 */
@Table(tableName = "f_config_adv_advertise", pkFieldName = "seqId", pkFieldAssign = false)
public class AdvAdvertise {
	private Long seqId;
	private String f_begin_date;
	private String f_end_date;
	private String adv_plat;
	private String adv_group_name;
	private Integer price_type;
	private String unit_price;
	private Integer is_advertise;
	private Integer is_enabled;
	private String remark;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;

    @Column(columnName="f_begin_date",isWhereColumn=true,operator=Operator.GE)
	private String from_date;
    @Column(columnName="f_end_date",isWhereColumn=true,operator=Operator.LE)
	private String to_date;
    
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getFrom_date() {
		return from_date;
	}
	public void setFrom_date(String from_date) {
		this.from_date = from_date;
	}
	public String getTo_date() {
		return to_date;
	}
	public void setTo_date(String to_date) {
		this.to_date = to_date;
	}
	public String getF_begin_date() {
		return f_begin_date;
	}
	public void setF_begin_date(String f_begin_date) {
		this.f_begin_date = f_begin_date;
	}
	public String getF_end_date() {
		return f_end_date;
	}
	public void setF_end_date(String f_end_date) {
		this.f_end_date = f_end_date;
	}
	public String getAdv_plat() {
		return adv_plat;
	}
	public void setAdv_plat(String adv_plat) {
		this.adv_plat = adv_plat;
	}
	public String getAdv_group_name() {
		return adv_group_name;
	}
	public void setAdv_group_name(String adv_group_name) {
		this.adv_group_name = adv_group_name;
	}
	public String getUnit_price() {
		return unit_price;
	}
	public void setUnit_price(String unit_price) {
		this.unit_price = unit_price;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getInputTime() {
		return inputTime;
	}
	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public Integer getPrice_type() {
		return price_type;
	}
	public void setPrice_type(Integer price_type) {
		this.price_type = price_type;
	}
	public Integer getIs_advertise() {
		return is_advertise;
	}
	public void setIs_advertise(Integer is_advertise) {
		this.is_advertise = is_advertise;
	}
	public Integer getIs_enabled() {
		return is_enabled;
	}
	public void setIs_enabled(Integer is_enabled) {
		this.is_enabled = is_enabled;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	@Override
	public String toString() {
		return "AdvAdvertise [f_begin_date=" + f_begin_date + ", f_end_date="
				+ f_end_date + ", adv_plat=" + adv_plat + ", adv_group_name="
				+ adv_group_name + ", price_type=" + price_type
				+ ", unit_price=" + unit_price + ", is_advertise="
				+ is_advertise + ", is_enabled=" + is_enabled + ", remark="
				+ remark + ", inputBy=" + inputBy + ", inputTime=" + inputTime
				+ ", editBy=" + editBy + ", editTime=" + editTime + "]";
	}
	
	
}
